*********************************************************************************************
**********                                                                         **********
**********        ARTICLE: Procyclicality of US Bank Leverage                      **********
**********        AUTHORS: Christian Laux, Thomas Rauter                           **********
**********        JOURNAL OF ACCOUNTING RESEARCH                                   **********
**********                                                                         **********
**********                                                                         **********
**********        TABLE OF CONTENTS:                                               **********
**********        -- A: Sample Formation and Variable Definitions                  **********
**********        -- B: Descriptive Statistics                                     **********
**********        -- C: Regressions - Published Paper                              **********
**********                                                                         **********
**********                                                                         **********
**********        README / DESCRIPTION:                                            **********
**********        This STATA do-file converts the raw data into our final          **********
**********        dataset and performs all statistical analyses. The code          **********
**********        uses the "bank_data_raw.xlsx" and "macro_data_raw.xlsx"          **********
**********        datasets as inputs and yields the content of the main            **********
**********        analysis (Tables 1 to 8 in paper) as output. To replicate        **********
**********        the results of our paper, select the banks listed in the file    **********
**********        "snl_institution_keys.txt", download the variables specified     **********
**********        in the spreadsheet "variable_description.xlsx" for Q1-1994 to    **********
**********        Q1-2013, and run the code.                                       **********
**********                                                                         **********
*********************************************************************************************

clear all
set more off
set matsize 5000
cd "" // Specify directory => copy path into "" //

capture log close
set logtype text
log using laux_rauter_procyclicality.txt, replace


*****************************************************************************************
*****************  A: SAMPLE FORMATION AND VARIABLE DEFINITIONS  ************************
*****************************************************************************************

////////////////  A.1. Import Raw GDP Data and Define GDP Growth  ///////////////////////

import excel "macro_data_raw.xlsx", firstrow clear // Import (long format) real GDP data (Q1-1994 to Q1-2013) from Bureau of Economic Analysis //
encode period, gen(period_no) // Create quarter ID; periods are calendar quarters //
label list period_no

sort period_no
gen real_gdpgrowth = ln(real_gdp[_n]) - ln(real_gdp[_n-1]) if (period_no[_n]==(period_no[_n-1]+1)) // Define GDP growth //
save "gdp_data.dta", replace
clear



////////////  A.2. Import Raw Bank-Level Data and Merge With GDP Data  //////////////////

import excel "bank_data_raw.xlsx", firstrow clear // Import (long format) bank data from SNL Financial (Q1-1994 to Q1-2013) //
encode period, gen(period_no) // Create quarter ID; periods are calendar quarters => defined in SNL(xl) before downloading the bank data //
label list period_no

merge m:1 period_no using "gdp_data.dta" // Merge datasets via quarter ID //
drop _merge



//////////////////////////////  A.3. Define Sample  /////////////////////////////////////

drop if totassets >=. // Remove observations with missing total assets //
drop if totequ >=. // Remove observations with missing (total) book equity //

drop if totequ <= 0 // Remove observations with non-positive book equity //
drop if totassets <= 0 // Remove observations with non-positive total assets //

drop if totassets <= 150000000 // Keep observations with total assets in excess of U$150 million //

sort instkey period_no // Sort by SNL institution key and and quarter ID //



///////////////////////  A.4. Generate Bank-Level Variables  //////////////////////////////

gen lev = (totassets / totequ)

gen q = marketcap / totequ
gen rw = rwa / totassets

gen fv = taccass + afssec
gen sec = taccass + afssec + htmsec 
gen totassetsbn = totassets / 1000000000

gen unusedcmt = uncmt_onefourrevlin + uncmt_creditcardlin + uncmt_totcommrelin + uncmt_secunderwrit + uncmt_othcmt
gen finassets = (taccass + afssec + htmsec + net_lns + cash_equ)
gen totliabilities = totassets - totequ
gen otherfinassets = (finassets - taccass - afssec - htmsec - net_lns)
gen otherliab =  totliabilities - totdep - seniordebt - totsubdebt


// Generate bank-level fractions //
foreach var of varlist taccass afssec htmsec net_lns otherfinassets finassets fv totdep seniordebt totsubdebt otherliab totliabilities {	
	gen `var'_frac = `var' / totassets
}


// Generate lagged variables //
sort instkey period_no 
foreach var of varlist totassets lev q rwcapitalratio { // defining a panel and using the lag command works equivalently (same results) //
	by instkey: gen `var'_lag1 = `var'[_n-1] if (period_no[_n] == (period_no[_n-1]+1))
}


gen lnsize_lag1 = ln(totassets_lag1)


// Generate "Accounting Items" //
foreach var of varlist chg_unrealgain netprofit gainsaleloan {
	gen `var'_norm = (`var' / totassets_lag1) * 1000
}


// Generate bank-level growth rates //
sort instkey period_no
foreach var of varlist lev totassets rw tot_assetssec unusedcmt net_lns sec cash_equ totdep seniordebt totsubdebt {
	by instkey: gen `var'growth = ln(`var'[_n]) - ln(`var'[_n-1]) if (period_no[_n] == (period_no[_n-1]+1))
}

replace rwgrowth = rwgrowth * 100 // Multiply delta risk weight with 100 for expositional purposes; total capital ratio_t-1 (rwcapitalratio_lag1) is already given in percent //

by instkey: gen goodwillgrowth = (gw[_n] - gw[_n-1]) / abs((totassets[_n] - totassets[_n-1])) if (period_no[_n] == (period_no[_n-1]+1)) // Define delta goodwill //



/////  A.5. Winsorize Bank-Level Growth Rates, Ratios, and Accounting Items  ////////////

foreach var of varlist lev q rw fv sec unusedcmt fv_frac lev_lag1 q_lag1 rwcapitalratio_lag1 chg_unrealgain_norm netprofit_norm gainsaleloan_norm levgrowth totassetsgrowth rwgrowth secgrowth net_lnsgrowth cash_equgrowth totdepgrowth seniordebtgrowth totsubdebtgrowth tot_assetssecgrowth unusedcmtgrowth goodwillgrowth taccass_frac afssec_frac htmsec_frac net_lns_frac otherfinassets_frac finassets_frac totdep_frac seniordebt_frac totsubdebt_frac otherliab_frac totliabilities_frac tieroneratio rwcapitalratio {	
	winsor `var', gen(w_`var') p(0.01)
}



///////////////  A.6. Implement Remaining Sample Selection Criteria /////////////////////

tab industry
gen industry_no = 1 if (industry == "Bank")
replace industry_no = 2 if (industry == "Savings Bank/Thrift/Mutual")
tab industry_no

drop if w_levgrowth >=. // Remove observations with missing values for book leverage growth //
drop if w_totassetsgrowth >=. // Remove observations with missing values for total asset growth //
drop if (industry_no == 1 & w_fv_frac >=.) // For commercial banks, remove observations with missing values for the fraction of fair value assets //



////////////////  A.7. Export SNL Institution Keys of Final Sample //////////////////////

preserve
sort instkey period_no
gen bank_count = 1
replace bank_count = 0 if (instkey[_n] == instkey[_n-1])
tab bank_count
keep if bank_count == 1 
keep instkey 
export delimited "snl_institution_keys.txt", novar
restore



*****************************************************************************************
**************************  B: DESCRIPTIVE STATISTICS  **********************************
*****************************************************************************************

// Define global variables for bank characteristics (Table 1) and descriptive statistics (Table 2) //
global Bank_Characteristics "w_taccass_frac w_afssec_frac w_htmsec_frac w_net_lns_frac w_otherfinassets_frac w_finassets_frac  w_rw  totassetsbn w_totdep_frac w_seniordebt_frac w_totsubdebt_frac w_otherliab_frac w_totliabilities_frac w_lev w_tieroneratio w_rwcapitalratio"
global Descriptive_Statistics "real_gdpgrowth w_totassetsgrowth w_levgrowth w_rwgrowth w_goodwillgrowth  w_chg_unrealgain_norm w_netprofit_norm w_gainsaleloan_norm w_rwcapitalratio_lag1 w_lev_lag1 w_q_lag1 lnsize_lag1"


////////////////////////////////// B.1. Table 1 /////////////////////////////////////////

estpost tabstat $Bank_Characteristics , statistics(mean p50 count) columns(statistics)
esttab using table_1_fullsample.rtf, cells(" mean(fmt(8)) p50(fmt(8)) count(fmt(0))") nomtitle nonumber replace

estpost tabstat $Bank_Characteristics if (industry_no == 2), statistics(mean p50 count) columns(statistics)
esttab using table_1_savings.rtf, cells(" mean(fmt(8)) p50(fmt(8)) count(fmt(0))") nomtitle nonumber replace

estpost tabstat $Bank_Characteristics if (industry_no == 1 & w_fv_frac < 0.20), statistics(mean p50 count) columns(statistics)
esttab using table_1_cbless.rtf, cells(" mean(fmt(8)) p50(fmt(8)) count(fmt(0))") nomtitle nonumber replace

estpost tabstat $Bank_Characteristics if (industry_no == 1 & w_fv_frac > 0.20), statistics(mean p50 count) columns(statistics)
esttab using table_1_cbmore.rtf, cells(" mean(fmt(8)) p50(fmt(8)) count(fmt(0))") nomtitle nonumber replace


////////////////////////////////// B.2. Table 2 /////////////////////////////////////////

estpost tabstat $Descriptive_Statistics , statistics(p1 p25 med mean p50 p75 p99 sd count) columns(statistics)
esttab using table_2_fullsample.rtf, cells(" p1(fmt(8)) p25(fmt(8)) p50(fmt(8)) mean(fmt(8)) p75(fmt(8)) p99(fmt(8)) sd(fmt(8))  count(fmt(0))") nomtitle nonumber replace

estpost tabstat $Descriptive_Statistics if (industry_no == 2), statistics(p1 p25 med mean p50 p75 p99 sd count) columns(statistics)
esttab using table_2_savings.rtf, cells(" p1(fmt(8)) p25(fmt(8)) p50(fmt(8)) mean(fmt(8)) p75(fmt(8)) p99(fmt(8)) sd(fmt(8))  count(fmt(0))") nomtitle nonumber replace

estpost tabstat $Descriptive_Statistics if (industry_no == 1 & w_fv_frac < 0.20), statistics(count p1 p25 med mean p50 p75 p99 sd) columns(statistics)
esttab using table_2_cbless.rtf, cells(" p1(fmt(8)) p25(fmt(8)) p50(fmt(8)) mean(fmt(8)) p75(fmt(8)) p99(fmt(8)) sd(fmt(8))  count(fmt(0))") nomtitle nonumber replace

estpost tabstat $Descriptive_Statistics if (industry_no == 1 & w_fv_frac > 0.20), statistics(count p1 p25 med mean p50 p75 p99 sd) columns(statistics)
esttab using table_2_cbmore.rtf, cells(" p1(fmt(8)) p25(fmt(8)) p50(fmt(8)) mean(fmt(8)) p75(fmt(8)) p99(fmt(8)) sd(fmt(8))  count(fmt(0))") nomtitle nonumber replace



*****************************************************************************************
**********************  C: REGRESSIONS - PUBLISHED PAPER  *******************************
*****************************************************************************************

// Define expansions and contractions of total assets and GDP //
gen tagrowth_up = 0
replace tagrowth_up = 1 if (w_totassetsgrowth > 0)

gen tagrowth_down = 0
replace tagrowth_down = 1 if (w_totassetsgrowth < 0)

gen gdpgrowth_up = 0
replace gdpgrowth_up = 1 if (real_gdpgrowth > 0)

gen gdpgrowth_down = 0
replace gdpgrowth_down = 1 if (real_gdpgrowth < 0)



////////////////////////////////// C.1. Table 3 /////////////////////////////////////////

// Define interaction terms //
gen w_totassetsgrowth_up = w_totassetsgrowth * tagrowth_up
gen w_totassetsgrowth_down = w_totassetsgrowth * tagrowth_down

gen real_gdpgrowth_up = real_gdpgrowth * gdpgrowth_up
gen real_gdpgrowth_down = real_gdpgrowth * gdpgrowth_down 

gen tagrowth_gdpgrowth_ia = w_totassetsgrowth * real_gdpgrowth


// Label variables //
label variable w_levgrowth "D_Book Leverage" // "D_" stands for delta //
label variable w_totassetsgrowth "D_Total Assets"
label variable real_gdpgrowth "D_GDP"
label variable w_totassetsgrowth_up "D_Total Assets * 1D_Total Assets>0"
label variable w_totassetsgrowth_down "D_Total Assets * 1D_Total Assets<0"
label variable real_gdpgrowth_up "D_GDP * 1D_GDP>0"
label variable real_gdpgrowth_down "D_GDP * 1D_GDP<0"
label variable tagrowth_gdpgrowth_ia "D_Total Assets * D_GDP"
label variable tagrowth_up "1D_Total Assets>0"
label variable gdpgrowth_up "1D_GDP>0"


// Run regressions of Table 3 //
eststo clear
eststo: reg w_levgrowth w_totassetsgrowth i.instkey i.period_no, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth_up w_totassetsgrowth_down tagrowth_up i.instkey i.period_no, vce(cluster instkey)
eststo: reg w_levgrowth real_gdpgrowth i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth real_gdpgrowth_up real_gdpgrowth_down gdpgrowth_up i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth real_gdpgrowth i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth tagrowth_gdpgrowth_ia w_totassetsgrowth real_gdpgrowth i.instkey, vce(cluster instkey)
eststo: reg w_totassetsgrowth real_gdpgrowth i.instkey, vce(cluster instkey)
eststo: reg w_totassetsgrowth real_gdpgrowth_up real_gdpgrowth_down gdpgrowth_up i.instkey, vce(cluster instkey)
esttab using table_3.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)



////////////////////////////////// C.2. Table 4 /////////////////////////////////////////

// Define interaction terms and remaining variables //
generate sb = 0
replace sb = 1 if (industry_no == 2)

gen fv20 = 0
replace fv20 = 1 if (industry_no == 1 & w_fv_frac > 0.20)

foreach var of varlist sb fv20 lnsize_lag1 {	
	gen tagrowth_`var' = w_totassetsgrowth * `var'
	gen gdpgrowth_`var' = real_gdpgrowth * `var'
	}


// Label variables //
label variable sb "1Savings Bank"
label variable fv20 "1CB>20%"
label variable lnsize_lag1 "Bank Size_t-1"
label variable tagrowth_sb "D_Total Assets * 1Savings Bank"
label variable tagrowth_fv20 "D_Total Assets * 1CB>20%"
label variable tagrowth_lnsize_lag1 "D_Total Assets * Bank Size_t-1"
label variable gdpgrowth_sb "D_GDP * 1Savings Bank"
label variable gdpgrowth_fv20 "D_GDP * 1CB>20%"
label variable gdpgrowth_lnsize_lag1 "D_GDP * Bank Size_t-1"


// Run regressions of Table 4 //
eststo clear
eststo: reg w_levgrowth w_totassetsgrowth real_gdpgrowth i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth tagrowth_sb tagrowth_fv20 real_gdpgrowth sb fv20, vce(cluster instkey)
/*
test tagrowth_sb = tagrowth_fv20 // Test whether coefficients are equal to each other //
*/
eststo: reg w_levgrowth w_totassetsgrowth tagrowth_sb tagrowth_fv20 tagrowth_lnsize_lag1 real_gdpgrowth lnsize_lag1 sb fv20, vce(cluster instkey)
/*
test tagrowth_sb = tagrowth_fv20
*/

eststo: reg w_levgrowth real_gdpgrowth gdpgrowth_sb gdpgrowth_fv20 w_totassetsgrowth sb fv20, vce(cluster instkey)
/*
test gdpgrowth_sb = gdpgrowth_fv20
*/
eststo: reg w_levgrowth real_gdpgrowth gdpgrowth_sb gdpgrowth_fv20 gdpgrowth_lnsize_lag1 w_totassetsgrowth lnsize_lag1 sb fv20, vce(cluster instkey)
/*
test gdpgrowth_sb = gdpgrowth_fv20
*/

eststo: reg w_levgrowth w_totassetsgrowth tagrowth_sb tagrowth_fv20 tagrowth_lnsize_lag1 real_gdpgrowth gdpgrowth_sb gdpgrowth_fv20 gdpgrowth_lnsize_lag1 lnsize_lag1 sb fv20, vce(cluster instkey)
/*
test tagrowth_sb =  tagrowth_fv20
*/
/*
test gdpgrowth_sb = gdpgrowth_fv20
*/

esttab using table_4.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey*)



///////////////////////////// C.3. Table 5 & Table 6 ////////////////////////////////////

// Define interaction terms //
foreach var of varlist w_chg_unrealgain_norm w_netprofit_norm w_rwcapitalratio_lag1 w_rwgrowth w_lev_lag1 {	
	gen tagr_`var'_up = w_totassetsgrowth * `var' * tagrowth_up
	gen tagr_`var'_down = w_totassetsgrowth * `var' * tagrowth_down
	
	gen gdpgr_`var'_up = real_gdpgrowth * `var' * gdpgrowth_up
	gen gdpgr_`var'_down = real_gdpgrowth * `var' * gdpgrowth_down
}


// Label variables //
label variable tagr_w_chg_unrealgain_norm_up "D_Total Assets * UG AFS * 1D_Total Assets>0"
label variable tagr_w_chg_unrealgain_norm_down "D_Total Assets * UG AFS * 1D_Total Assets<0"
label variable tagr_w_netprofit_norm_up "D_Total Assets * NI * 1D_Total Assets>0"
label variable tagr_w_netprofit_norm_down "D_Total Assets * NI * 1D_Total Assets<0"
label variable tagr_w_rwcapitalratio_lag1_up "D_Total Assets * TotCapRatio_t-1 * 1D_Total Assets>0"
label variable tagr_w_rwcapitalratio_lag1_down "D_Total Assets * TotCapRatio_t-1 * 1D_Total Assets<0"
label variable tagr_w_rwgrowth_up "D_Total Assets * D_RW * 1D_Total Assets>0"
label variable tagr_w_rwgrowth_down "D_Total Assets * D_RW * 1D_Total Assets<0"
label variable tagr_w_lev_lag1_up "D_Total Assets * Lev_t-1 * 1D_Total Assets>0"
label variable tagr_w_lev_lag1_down "D_Total Assets * Lev_t-1 * 1D_Total Assets<0"
label variable w_chg_unrealgain_norm "UG AFS"
label variable w_netprofit_norm "NI"
label variable w_rwcapitalratio_lag1 "TotCapRatio_t-1"
label variable w_rwgrowth "D_RW"
label variable w_q_lag1 "q_t-1"
label variable w_lev_lag1 "Lev_t-1"
label variable w_goodwillgrowth "D_GW"

label variable gdpgr_w_chg_unrealgain_norm_up "D_GDP * UG AFS * 1D_GDP>0"
label variable gdpgr_w_chg_unrealgain_norm_down "D_GDP * UG AFS * 1D_GDP<0"
label variable gdpgr_w_netprofit_norm_up "D_GDP * NI * 1D_GDP>0"
label variable gdpgr_w_netprofit_norm_down "D_GDP * NI * 1D_GDP<0"
label variable gdpgr_w_rwcapitalratio_lag1_up "D_GDP * TotCapRatio_t-1 * 1D_GDP>0"
label variable gdpgr_w_rwcapitalratio_lag1_down "D_GDP * TotCapRatio_t-1 * 1D_GDP<0"
label variable gdpgr_w_rwgrowth_up "D_GDP * D_RW * 1D_GDP>0"
label variable gdpgr_w_rwgrowth_down "D_GDP * D_RW * 1D_GDP<0"
label variable gdpgr_w_lev_lag1_up "D_GDP * Lev_t-1 * 1D_GDP>0"
label variable gdpgr_w_lev_lag1_down "D_GDP * Lev_t-1 * 1D_GDP<0"


// Define global variables (for expositional purposes in regression commands) //
global Interactions_D_Total_Assets "tagr_w_chg_unrealgain_norm_up tagr_w_chg_unrealgain_norm_down tagr_w_netprofit_norm_up tagr_w_netprofit_norm_down tagr_w_rwcapitalratio_lag1_up tagr_w_rwcapitalratio_lag1_down tagr_w_rwgrowth_up tagr_w_rwgrowth_down tagr_w_lev_lag1_up tagr_w_lev_lag1_down"
global Interactions_D_GDP "gdpgr_w_chg_unrealgain_norm_up gdpgr_w_chg_unrealgain_norm_down gdpgr_w_netprofit_norm_up gdpgr_w_netprofit_norm_down gdpgr_w_rwcapitalratio_lag1_up gdpgr_w_rwcapitalratio_lag1_down gdpgr_w_rwgrowth_up gdpgr_w_rwgrowth_down gdpgr_w_lev_lag1_up gdpgr_w_lev_lag1_down"
global Stand_Alone_Variables "w_chg_unrealgain_norm w_netprofit_norm w_rwcapitalratio_lag1 w_rwgrowth w_lev_lag1"
global Controls "lnsize_lag1 w_q_lag1 w_goodwillgrowth"


// Run regressions of Table 5 //
eststo clear
eststo: reg w_levgrowth w_totassetsgrowth $Interactions_D_Total_Assets real_gdpgrowth $Stand_Alone_Variables $Controls tagrowth_up i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth $Interactions_D_Total_Assets real_gdpgrowth $Stand_Alone_Variables $Controls tagrowth_up i.instkey if (industry_no == 2), vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth $Interactions_D_Total_Assets real_gdpgrowth $Stand_Alone_Variables $Controls tagrowth_up i.instkey if (industry_no == 1 & w_fv_frac < 0.20), vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth $Interactions_D_Total_Assets real_gdpgrowth $Stand_Alone_Variables $Controls tagrowth_up i.instkey if (industry_no == 1 & w_fv_frac > 0.20), vce(cluster instkey)
esttab using table_5.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey*)


// Run regressions of Table 6 //
eststo clear
eststo: reg w_levgrowth real_gdpgrowth $Interactions_D_GDP w_totassetsgrowth $Stand_Alone_Variables $Controls gdpgrowth_up i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth real_gdpgrowth $Interactions_D_GDP w_totassetsgrowth $Stand_Alone_Variables $Controls gdpgrowth_up i.instkey if (industry_no == 2), vce(cluster instkey)
eststo: reg w_levgrowth real_gdpgrowth $Interactions_D_GDP w_totassetsgrowth $Stand_Alone_Variables $Controls gdpgrowth_up i.instkey if (industry_no == 1 & w_fv_frac < 0.20), vce(cluster instkey)
eststo: reg w_levgrowth real_gdpgrowth $Interactions_D_GDP w_totassetsgrowth $Stand_Alone_Variables $Controls gdpgrowth_up i.instkey if (industry_no == 1 & w_fv_frac > 0.20), vce(cluster instkey)
esttab using table_6.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey*)



////////////////////////////////// C.4. Table 7 /////////////////////////////////////////

// Define interaction terms //
foreach var of varlist w_net_lnsgrowth w_secgrowth w_cash_equgrowth w_totdepgrowth w_seniordebtgrowth w_totsubdebtgrowth {	
	gen `var'_up = `var' * tagrowth_up
	gen `var'_down = `var' * tagrowth_down
}


// Label variables //
label variable w_net_lnsgrowth_up "D_Loans * 1D_Total Assets>0"
label variable w_net_lnsgrowth_down "D_Loans * 1D_Total Assets<0"
label variable w_secgrowth_up "D_Securities * 1D_Total Assets>0"
label variable w_secgrowth_down "D_Securities * 1D_Total Assets<0"
label variable w_cash_equgrowth_up "D_Cash * 1D_Total Assets>0"
label variable w_cash_equgrowth_down "D_Cash * 1D_Total Assets<0"
label variable w_totdepgrowth_up "D_Deposits * 1D_Total Assets>0"
label variable w_totdepgrowth_down "D_Deposits * 1D_Total Assets<0"
label variable w_seniordebtgrowth_up "D_Senior Debt * 1D_Total Assets>0"
label variable w_seniordebtgrowth_down "D_Senior Debt * 1D_Total Assets<0"
label variable w_totsubdebtgrowth_up "D_Subordinated Debt * 1D_Total Assets>0"
label variable w_totsubdebtgrowth_down "D_Subordinated Debt * 1D_Total Assets<0"


// Define global variables (for expositional purposes) //
global Asset_Component_Analysis "w_net_lnsgrowth_up w_net_lnsgrowth_down w_secgrowth_up w_secgrowth_down w_cash_equgrowth_up w_cash_equgrowth_down"
global Liability_Component_Analysis "w_totdepgrowth_up w_totdepgrowth_down w_seniordebtgrowth_up w_seniordebtgrowth_down w_totsubdebtgrowth_up w_totsubdebtgrowth_down"


/// Run regressions of Table 7 - Panel A ///
eststo clear
eststo: reg w_levgrowth $Asset_Component_Analysis tagrowth_up i.instkey i.period_no, vce(cluster instkey)
esttab using table_7_a1.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)

eststo clear
eststo: reg w_levgrowth $Asset_Component_Analysis tagrowth_up i.instkey i.period_no if (industry_no == 2), vce(cluster instkey)
esttab using table_7_a2.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)

eststo clear
eststo: reg w_levgrowth $Asset_Component_Analysis tagrowth_up i.instkey i.period_no if (industry_no == 1 & w_fv_frac < 0.20), vce(cluster instkey)
esttab using table_7_a3.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)

eststo clear
eststo: reg w_levgrowth $Asset_Component_Analysis tagrowth_up i.instkey i.period_no if (industry_no == 1 & w_fv_frac > 0.20), vce(cluster instkey)
esttab using table_7_a4.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)


/// Run regressions of Table 7 - Panel B ///
eststo clear
eststo: reg w_levgrowth $Liability_Component_Analysis tagrowth_up i.instkey i.period_no, vce(cluster instkey)
esttab using table_7_b1.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)

eststo clear
eststo: reg w_levgrowth $Liability_Component_Analysis tagrowth_up i.instkey i.period_no if (industry_no == 2), vce(cluster instkey)
esttab using table_7_b2.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)

eststo clear
eststo: reg w_levgrowth $Liability_Component_Analysis tagrowth_up i.instkey i.period_no if (industry_no == 1 & w_fv_frac < 0.20), vce(cluster instkey)
esttab using table_7_b3.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)

eststo clear
eststo: reg w_levgrowth $Liability_Component_Analysis tagrowth_up i.instkey i.period_no if (industry_no == 1 & w_fv_frac > 0.20), vce(cluster instkey)
esttab using table_7_b4.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey* *period_no*)



////////////////////////////////// C.5. Table 8 /////////////////////////////////////////

// Define interaction terms //
foreach var of varlist w_unusedcmtgrowth w_tot_assetssecgrowth w_gainsaleloan_norm {	
	gen tagr_`var'_up = w_totassetsgrowth * `var' * tagrowth_up
	gen tagr_`var'_down = w_totassetsgrowth * `var' * tagrowth_down
	
	gen gdpgr_`var'_up = real_gdpgrowth * `var' * gdpgrowth_up
	gen gdpgr_`var'_down = real_gdpgrowth * `var' * gdpgrowth_down
}


// Label variables //
label variable tagr_w_unusedcmtgrowth_up "D_Total Assets * D_Loan Commitments * 1D_Total Assets>0"
label variable tagr_w_unusedcmtgrowth_down "D_Total Assets * D_Loan Commitments * 1D_Total Assets<0"
label variable tagr_w_tot_assetssecgrowth_up "D_Total Assets * D_Sec. Assets * 1D_Total Assets>0"
label variable tagr_w_tot_assetssecgrowth_down "D_Total Assets * D_Sec. Assets * 1D_Total Assets<0"
label variable tagr_w_gainsaleloan_norm_up "D_Total Assets * Realized Gains Loans * 1D_Total Assets>0"
label variable tagr_w_gainsaleloan_norm_down "D_Total Assets * Realized Gains Loans * 1D_Total Assets<0"
label variable gdpgr_w_unusedcmtgrowth_up "D_GDP * D_Loan Commitments * 1D_GDP>0"
label variable gdpgr_w_unusedcmtgrowth_down "D_GDP * D_Loan Commitments * 1D_GDP<0"
label variable gdpgr_w_tot_assetssecgrowth_up "D_GDP * D_Sec. Assets * 1D_GDP>0"
label variable gdpgr_w_tot_assetssecgrowth_down "D_GDP * D_Sec. Assets * 1D_GDP<0"
label variable gdpgr_w_gainsaleloan_norm_up "D_GDP * Realized Gains Loans * 1D_GDP>0"
label variable gdpgr_w_gainsaleloan_norm_down "D_GDP * Realized Gains Loans * 1D_GDP<0"
label variable w_unusedcmtgrowth "D_Loan Commitments"
label variable w_tot_assetssecgrowth "D_Sec. Assets"
label variable w_gainsaleloan_norm "Realized Gains Loans"


/// Run regressions of Table 8 ///
eststo clear
eststo: reg w_levgrowth w_totassetsgrowth real_gdpgrowth w_unusedcmtgrowth w_lev_lag1 lnsize_lag1 w_q_lag1 w_goodwillgrowth i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth tagr_w_unusedcmtgrowth_up tagr_w_unusedcmtgrowth_down real_gdpgrowth gdpgr_w_unusedcmtgrowth_up gdpgr_w_unusedcmtgrowth_down w_unusedcmtgrowth w_lev_lag1 lnsize_lag1 w_q_lag1 w_goodwillgrowth tagrowth_up gdpgrowth_up i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth real_gdpgrowth w_tot_assetssecgrowth w_lev_lag1 lnsize_lag1 w_q_lag1 w_goodwillgrowth i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth tagr_w_tot_assetssecgrowth_up tagr_w_tot_assetssecgrowth_down real_gdpgrowth gdpgr_w_tot_assetssecgrowth_up gdpgr_w_tot_assetssecgrowth_down w_tot_assetssecgrowth w_lev_lag1 lnsize_lag1 w_q_lag1 w_goodwillgrowth tagrowth_up gdpgrowth_up i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth real_gdpgrowth w_gainsaleloan_norm w_lev_lag1 lnsize_lag1 w_q_lag1 w_goodwillgrowth i.instkey, vce(cluster instkey)
eststo: reg w_levgrowth w_totassetsgrowth tagr_w_gainsaleloan_norm_up tagr_w_gainsaleloan_norm_down real_gdpgrowth gdpgr_w_gainsaleloan_norm_up gdpgr_w_gainsaleloan_norm_down w_gainsaleloan_norm  w_lev_lag1 lnsize_lag1 w_q_lag1 w_goodwillgrowth tagrowth_up gdpgrowth_up i.instkey, vce(cluster instkey)
esttab using table_8.rtf, label se r2 star(* 0.10 ** 0.05 *** 0.01) b(3) se(3) replace drop (*instkey*)


log close
clear
